util
============================================

Miscellaneous util functions native to scalecast.

metrics
----------
.. autoclass:: src.scalecast.util.metrics
   :members:

backtest_metrics()
-------------------------
.. autofunction:: src.scalecast.util.backtest_metrics

break_mv_forecaster()
-----------------------------
.. autofunction:: src.scalecast.util.break_mv_forecaster

find_optimal_coint_rank()
----------------------------
.. autofunction:: src.scalecast.util.find_optimal_coint_rank

find_optimal_lag_order()
---------------------------
.. autofunction:: src.scalecast.util.find_optimal_lag_order

find_optimal_transformation()
-----------------------------------
.. autofunction:: src.scalecast.util.find_optimal_transformation

find_statistical_transformation()
-----------------------------------
.. autofunction:: src.scalecast.util.find_statistical_transformation
plot_reduction_errors()
-----------------------------
.. autofunction:: src.scalecast.util.plot_reduction_errors
